from pyo3_tonic_greeter_example import serve_greeter, HelloRequest, HelloResponse
import asyncio


def hello(request: HelloRequest) -> HelloResponse:
    return HelloResponse(f'Hello {request.name}!')


async def main():
    await serve_greeter(hello)

asyncio.run(main())



from typing import Callable


class HelloRequest:
    name: str
    def __new__(cls, name: str) -> HelloRequest: ...


class HelloResponse:
    message: str
    def __new__(cls, message: str) -> HelloResponse: ...


async def serve_greeter(
    hello: Callable[[HelloRequest], HelloResponse], port=50051): ...
